"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .platforms import Platforms
from polar_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import TypedDict


class ExternalOrganizationTypedDict(TypedDict):
    id: str
    platform: Platforms
    name: str
    avatar_url: str
    is_personal: bool
    bio: Nullable[str]
    pretty_name: Nullable[str]
    company: Nullable[str]
    blog: Nullable[str]
    location: Nullable[str]
    email: Nullable[str]
    twitter_username: Nullable[str]
    organization_id: Nullable[str]


class ExternalOrganization(BaseModel):
    id: str

    platform: Platforms

    name: str

    avatar_url: str

    is_personal: bool

    bio: Nullable[str]

    pretty_name: Nullable[str]

    company: Nullable[str]

    blog: Nullable[str]

    location: Nullable[str]

    email: Nullable[str]

    twitter_username: Nullable[str]

    organization_id: Nullable[str]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = [
            "bio",
            "pretty_name",
            "company",
            "blog",
            "location",
            "email",
            "twitter_username",
            "organization_id",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .customersubscriptioncancel import (
    CustomerSubscriptionCancel,
    CustomerSubscriptionCancelTypedDict,
)
from .customersubscriptionupdateprice import (
    CustomerSubscriptionUpdatePrice,
    CustomerSubscriptionUpdatePriceTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


CustomerSubscriptionUpdateTypedDict = TypeAliasType(
    "CustomerSubscriptionUpdateTypedDict",
    Union[
        CustomerSubscriptionUpdatePriceTypedDict, CustomerSubscriptionCancelTypedDict
    ],
)


CustomerSubscriptionUpdate = TypeAliasType(
    "CustomerSubscriptionUpdate",
    Union[CustomerSubscriptionUpdatePrice, CustomerSubscriptionCancel],
)
